@@ -4,19 +4,18 @@ use strict;
 use warnings::register;
 
 use Pipeline;
-our $VERSION = "2.05";
-
-sub new {
-  my $class = shift;
-  my $self  = {};
-  bless $self, $class;
-  $self->init();
-  return $self;
-}
+use Pipeline::Base;
+use base qw(Pipeline::Base);
+our $VERSION = 3.01;
 
 sub init {
   my $self = shift;
-  $self->pipe( Pipeline->new() );
+  if ($self->SUPER::init( @_ )) {
+    $self->pipe( Pipeline->new() );
+    return 1;
+  } else {
+    return 0;
+  }
 }
 
 sub pipe {
